@@ -2,7 +2,7 @@ from requests.cookies import RequestsCookieJar
 
 
 def normalize_cookies(cookies):
-    """Takes cookies from PhantomJS/Selenium or from Python Requests and
+    """Takes cookies from Selenium or from Python Requests and
     converts them to dict.
 
     This throws away information that Selenium otherwise has (like the host and
@@ -10,7 +10,7 @@ def normalize_cookies(cookies):
     """
     requests_cookies = {}
     if type(cookies) == list:
-        # Phantom/Selenium cookies
+        # Selenium cookies
         for cookie in cookies:
             requests_cookies[cookie["name"]] = cookie["value"]
     elif type(cookies) == RequestsCookieJar:
