@@ -23,9 +23,13 @@ class Site(OpinionSite):
         super(Site, self).__init__(*args, **kwargs)
         self.court_id = self.__module__
         # Cases before 1997 do not have a docket number to parse.
-        url_query = '&DB='.join(
-            [str(n) for n in range(datetime.today().year, 1997 - 1, -1)])
-        self.url = 'http://www.index.va.gov/search/va/bva_search.jsp?RPP=50&RS=1&DB=%s' % url_query
+        url_query = "&DB=".join(
+            [str(n) for n in range(datetime.today().year, 1997 - 1, -1)]
+        )
+        self.url = (
+            "http://www.index.va.gov/search/va/bva_search.jsp?RPP=50&RS=1&DB=%s"
+            % url_query
+        )
         self.pager_stop = False
         self.back_scrape_iterable = self.pager(50)
         self.cases = []
@@ -44,7 +48,7 @@ class Site(OpinionSite):
     def _extract_case_data_from_html(self, html):
         """Build list of data dictionaries, one dictionary per case."""
         regex = re.compile(
-            r'^Citation Nr: (.*) Decision Date: (.*) Archive Date: (.*) DOCKET NO. ([-0-9 ]+)'
+            r"^Citation Nr: (.*) Decision Date: (.*) Archive Date: (.*) DOCKET NO. ([-0-9 ]+)"
         )
 
         for result in html.xpath('//div[@id="results-area"]/div/a'):
@@ -53,39 +57,44 @@ class Site(OpinionSite):
                 (citation, date, docket) = regex.match(text).group(1, 2, 4)
             except:
                 raise Exception(
-                    'regex failure in _extract_case_data_from_html method of bva scraper'
+                    "regex failure in _extract_case_data_from_html method of bva scraper"
                 )
 
             # There is a history to this, but the long story short is that we
             # are using the docket number in the name field intentionally.
-            self.cases.append({
-                'name': docket,
-                'url': result.xpath('.//@href')[0],
-                'date': convert_date_string(date),
-                'status': 'Unpublished',
-                'docket': docket,
-                'citation': citation.split()[0],
-            })
+            self.cases.append(
+                {
+                    "name": docket,
+                    "url": result.xpath(".//@href")[0],
+                    "date": convert_date_string(date),
+                    "status": "Unpublished",
+                    "docket": docket,
+                    "citation": citation.split()[0],
+                }
+            )
 
     def _get_case_dates(self):
-        return [case['date'] for case in self.cases]
+        return [case["date"] for case in self.cases]
 
     def _get_download_urls(self):
-        return [case['url'] for case in self.cases]
+        return [case["url"] for case in self.cases]
 
     def _get_case_names(self):
-        return [case['name'] for case in self.cases]
+        return [case["name"] for case in self.cases]
 
     def _get_docket_numbers(self):
-        return [case['docket'] for case in self.cases]
+        return [case["docket"] for case in self.cases]
 
     def _get_precedential_statuses(self):
-        return [case['status'] for case in self.cases]
+        return [case["status"] for case in self.cases]
 
     def _download_backwards(self, startat):
-        base_url = 'http://www.index.va.gov/search/va/bva_search.jsp?RPP=50&RS=%d' % (
-        startat,)
+        base_url = (
+            "http://www.index.va.gov/search/va/bva_search.jsp?RPP=50&RS=%d"
+            % (startat,)
+        )
         date_range = range(datetime.today().year, 1997 - 1, -1)
-        self.url = base_url + '&DB=' + '&DB='.join([str(n) for n in date_range])
+        self.url = (
+            base_url + "&DB=" + "&DB=".join([str(n) for n in date_range])
+        )
         self.html = self._download()
-
