@@ -11,26 +11,29 @@ from dateutil.rrule import rrule, DAILY
 class Site(OpinionSite):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
-        self.url = 'http://www.ca4.uscourts.gov/DataOpinions.aspx'
+        self.url = "http://www.ca4.uscourts.gov/DataOpinions.aspx"
         self.court_id = self.__module__
         td = date.today()
         self.parameters = {
-            'CASENUM': '',
-            'FROMDATE': (td - timedelta(days=10)).strftime('%m-%d-%Y'),
-            'TITLE': '',
-            'TODATE': td.strftime('%m-%d-%Y')
+            "CASENUM": "",
+            "FROMDATE": (td - timedelta(days=10)).strftime("%m-%d-%Y"),
+            "TITLE": "",
+            "TODATE": td.strftime("%m-%d-%Y"),
         }
-        self.method = 'POST'
+        self.method = "POST"
         self.interval = 30
-        self.back_scrape_iterable = [i.date() for i in rrule(
-            DAILY,
-            interval=self.interval,  # Every interval days
-            dtstart=date(1996, 1, 1),
-            until=date(2016, 1, 1),
-        )]
+        self.back_scrape_iterable = [
+            i.date()
+            for i in rrule(
+                DAILY,
+                interval=self.interval,  # Every interval days
+                dtstart=date(1996, 1, 1),
+                until=date(2016, 1, 1),
+            )
+        ]
 
     def _get_case_names(self):
-        path = '//tr/td[4]/text()'
+        path = "//tr/td[4]/text()"
         names = []
         for s in self.html.xpath(path):
             s = clean_if_py3(s)
@@ -40,20 +43,22 @@ class Site(OpinionSite):
         return names
 
     def _get_download_urls(self):
-        path = '//tr/td[1]/a/@href'
+        path = "//tr/td[1]/a/@href"
         return list(self.html.xpath(path))
 
     def _get_case_dates(self):
-        path = '//tr/td[3]/text()'
+        path = "//tr/td[3]/text()"
         case_dates = []
         for date_string in self.html.xpath(path):
             date_string = clean_if_py3(date_string).strip()
             if date_string:
-                case_dates.append(datetime.strptime(date_string, '%m/%d/%Y').date())
+                case_dates.append(
+                    datetime.strptime(date_string, "%m/%d/%Y").date()
+                )
         return case_dates
 
     def _get_docket_numbers(self):
-        path = '//tr/td[2]//text()'
+        path = "//tr/td[2]//text()"
         docket_numbers = []
         for s in self.html.xpath(path):
             s = clean_if_py3(s).strip()
@@ -65,20 +70,20 @@ class Site(OpinionSite):
         statuses = []
         # using download link, we can get the statuses
         for download_url in self.download_urls:
-            file_name = download_url.split('/')[-1]
-            if 'u' in file_name.lower():
-                statuses.append('Unpublished')
+            file_name = download_url.split("/")[-1]
+            if "u" in file_name.lower():
+                statuses.append("Unpublished")
             else:
-                statuses.append('Published')
+                statuses.append("Published")
         return statuses
 
     def _download_backwards(self, d):
 
         self.parameters = {
-            'CASENUM': '',
-            'FROMDATE': d.strftime('%m-%d-%Y'),
-            'TITLE': '',
-            'TODATE': (d + timedelta(self.interval)).strftime('%m-%d-%Y')
+            "CASENUM": "",
+            "FROMDATE": d.strftime("%m-%d-%Y"),
+            "TITLE": "",
+            "TODATE": (d + timedelta(self.interval)).strftime("%m-%d-%Y"),
         }
 
         self.html = self._download()
