@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 # Scraper for the United States Tax Court
 # CourtID: tax
 # Court Short Name: Tax Ct.
@@ -5,22 +6,17 @@
 # Neutral Citation Format (Memorandum opinions): T.C. Memo 2012-1
 # Neutral Citation Format (Summary opinions: T.C. Summary Opinion 2012-1
 
-import os
 import re
 from datetime import date, datetime, timedelta
-
 from dateutil.rrule import WEEKLY, rrule
-from selenium import webdriver
-from selenium.webdriver.common.by import By
-from selenium.webdriver.support import expected_conditions as EC
-from selenium.webdriver.support.wait import WebDriverWait
 
-from juriscraper.AbstractSite import logger, phantomjs_executable_path
-from juriscraper.OpinionSite import OpinionSite
+from juriscraper.AbstractSite import logger
+from juriscraper.OpinionSiteWebDriven import OpinionSiteWebDriven
 from juriscraper.lib.html_utils import fix_links_but_keep_anchors
+from juriscraper.lib.models import citation_types
 
 
-class Site(OpinionSite):
+class Site(OpinionSiteWebDriven):
     def __init__(self, *args, **kwargs):
         super(Site, self).__init__(*args, **kwargs)
         self.uses_selenium = True
@@ -44,17 +40,12 @@ class Site(OpinionSite):
         if self.test_mode_enabled():
             return super(Site, self)._download(request_dict=request_dict)
 
-        driver = webdriver.PhantomJS(
-            executable_path=phantomjs_executable_path,
-            service_log_path=os.path.devnull,  # Disable ghostdriver.log
-        )
-        driver.implicitly_wait(30)
         logger.info("Now downloading case page at: %s" % self.url)
-        driver.get(self.url)
+        self.initiate_webdriven_session()
 
         # Set the start and end dates
         start_date_id = "ctl00_Content_dpDateSearch_dateInput"
-        start_date_input = driver.find_element_by_id(start_date_id)
+        start_date_input = self.webdriver.find_element_by_id(start_date_id)
         start_date_input.send_keys(
             (self.case_date - timedelta(days=self.backwards_days)).strftime(
                 "%-m/%-d/%Y"
@@ -62,28 +53,23 @@ class Site(OpinionSite):
         )
 
         end_date_id = "ctl00_Content_dpDateSearchTo_dateInput"
-        end_date_input = driver.find_element_by_id(end_date_id)
+        end_date_input = self.webdriver.find_element_by_id(end_date_id)
         end_date_input.send_keys(self.case_date.strftime("%-m/%-d/%Y"))
-        # driver.save_screenshot('%s.png' % self.case_date)
+        # self.take_screenshot()
 
         # Check ordering by case date (this orders by case date, *ascending*)
         ordering_id = "Content_rdoCaseName_1"
-        driver.find_element_by_id(ordering_id).click()
+        self.webdriver.find_element_by_id(ordering_id).click()
 
         # Submit
-        driver.find_element_by_id("Content_btnSearch").click()
+        self.webdriver.find_element_by_id("Content_btnSearch").click()
 
         # Do not proceed until the results show up.
-        wait = WebDriverWait(driver, 10)
-        wait.until(
-            EC.presence_of_element_located(
-                (By.ID, "Content_ddlResultsPerPage")
-            )
-        )
-        # driver.save_screenshot('with-results.png')
+        self.wait_for_id("Content_ddlResultsPerPage")
+        # self.take_screenshot()
 
-        text = self._clean_text(driver.page_source)
-        driver.quit()
+        text = self._clean_text(self.webdriver.page_source)
+        self.webdriver.quit()
         html_tree = self._make_html_tree(text)
         html_tree.rewrite_links(fix_links_but_keep_anchors, base_href=self.url)
         return html_tree
@@ -168,7 +154,8 @@ class Site(OpinionSite):
         :return: dictionary of citations, reporter, volume and page
         """
         metadata = {
-            "Citation": {"type": "SPECIALTY"},
+            "Citation": {"type": citation_types["SPECIALTY"]},
+            "Docket": {"docket_number": ""},
             "OpinionCluster": {"precedential_status": ""},
         }
 
@@ -187,7 +174,7 @@ class Site(OpinionSite):
             ([0-9]{4})                                          # Four digit year (volume)
             .                                                   # hyphen, em-dash etc.
             ([0-9]{1,3})\b)                                     # 1-3 digit number in order of publication (page)
-            |                                                   # or 
+            |                                                   # or
             ([0-9]{1,4})\s{1,}                                  # (volume)
             (T\.\ ?C\.\ No\.)(?:\s{1,})?                        # T.C. No. (reporter)
             (\d{1,4}))                                          # (page)
@@ -225,4 +212,48 @@ class Site(OpinionSite):
                         "precedential_status"
                     ] = "Unpublished"
 
+        metadata["Docket"]["docket_number"] = self.get_tax_docket_numbers(
+            scraped_text
+        )
         return metadata
+
+    def get_tax_docket_numbers(self, opinion_text):
+        """Parse opinion plain text for docket numbers.
+
+        First we idenitify where the docket numbers are in the document.
+        This is normally at the start of the document but can often follow
+         a lengthy case details section.
+
+        :param opinion_text: is the opinions plain_text
+        :return docket_string: as string of docket numbers Ex. (18710-94, 12321-95)
+        """
+        opinion_text = self.remove_en_em_dash(opinion_text)
+        parsed_text = ""
+        docket_no_re = r"Docket.? Nos?.? .*[0-9]{3,5}"
+        matches = re.finditer(docket_no_re, opinion_text)
+
+        for matchNum, match in enumerate(matches, start=1):
+            parsed_text = opinion_text[match.start() :]
+            break
+
+        matches2 = re.finditer(
+            r"[0-9]{3,5}(-|–)[\w]{2,4}([A-Z])?((\.)| [A-Z]\.)", parsed_text
+        )
+        for m2, match2 in enumerate(matches2, start=0):
+            parsed_text = parsed_text[: match2.end()]
+            break
+
+        docket_end_re = r"[0-9]{3,5}(-|–)[\w]{2,4}([A-Z])?((\,|\.)| [A-Z]\.)"
+
+        matches = re.finditer(docket_end_re, parsed_text, re.MULTILINE)
+        hits = []
+        for matchNum, match in enumerate(matches, start=1):
+            hits.append(match.group())
+        docket_string = ", ".join(hits).replace(",,", ",").replace(".", "")
+        return docket_string.strip()
+
+    def remove_en_em_dash(self, opinion_text):
+        opinion_text = re.sub(u"–", "-", opinion_text)
+        opinion_text = re.sub(u"—", "-", opinion_text)
+        opinion_text = re.sub(u"–", "-", opinion_text)
+        return opinion_text
