@@ -4,6 +4,7 @@ This is pretty limited metadata about the case, although it
 presents some more information for BK cases.
 """
 import pprint
+import re
 import sys
 
 from six.moves import range
@@ -28,8 +29,14 @@ class CaseQuery(BaseDocketReport, BaseReport):
 
     CACHE_ATTRS = ["metadata"]
 
+    ERROR_STRINGS = BaseReport.ERROR_STRINGS + [
+        r"Case not found\.",
+    ]
+
     def __init__(self, court_id, pacer_session=None):
-        super(CaseQuery, self).__init__(court_id, pacer_session)
+        BaseDocketReport.__init__(self, court_id)
+        BaseReport.__init__(self, court_id, pacer_session)
+
         # Initialize the empty cache properties
         self._clear_caches()
         self._metadata = None
@@ -40,6 +47,9 @@ class CaseQuery(BaseDocketReport, BaseReport):
 
     @property
     def metadata(self):
+        if self.is_valid is False:
+            return {}
+
         if self._metadata is not None:
             return self._metadata
 
@@ -116,7 +126,9 @@ class CaseQuery(BaseDocketReport, BaseReport):
         #   <B><FONT SIZE=+1>18-11572</FONT></B><B></B>Nancy Jean Stevens
         # We take the docket number from the <font> tag (the innermost tag),
         # although we could but have chosen the first <b> tag.
-        docket_number = force_unicode(rows[0].find(".//font").text_content())
+        docket_number = self._parse_docket_number_strs(
+            [rows[0].find(".//font").text_content()]
+        )
         # And case caption following the final <b></b> pair.
         case_name_raw = force_unicode(rows[0].find(".//b[last()]").tail)
 
@@ -137,30 +149,35 @@ class CaseQuery(BaseDocketReport, BaseReport):
             u"date_of_last_filing": u"date_last_filing",
             u"judge": u"assigned_to_str",
             u"plan_confirmed": u"date_plan_confirmed",
+            u"debtor_discharged": u"date_debtor_dismissed",
+            u"joint_debtor_discharged": u"date_joint_debtor_dismissed",
         }
         for i in range(1, len(rows) - 1):
             bolds = rows[i].findall(".//b")
             if not bolds:
-                if i == 1:
-                    # Second row, no bold => judge name!
-                    judge_role = force_unicode(rows[i].text_content())
-                    PRESIDING = ", presiding"
-                    assert judge_role.endswith(PRESIDING), (
-                        "We expected the judge's name to end with "
-                        "', presiding'."
-                    )
-                    data[u"assigned_to_str"] = judge_role.rstrip(PRESIDING)
-                elif i == 2:
-                    # Third row, no bold => referred judge name!
-                    judge_role = force_unicode(rows[i].text_content())
-                    REFERRAL = ", referral"
-                    assert judge_role.endswith(REFERRAL), (
-                        "We expected the referred judge's name to end "
-                        "with , referral"
-                    )
-                    data[u"referred_to_str"] = judge_role.rstrip(REFERRAL)
+                line = force_unicode(rows[i].text_content())
+                if not line:
+                    continue
+
+                if re.search(r"(panel [2-3]$|Probation)", line):
+                    # Skip panelists after the first, skip probation
+                    # assignments
+                    continue
+
+                if i == 1 or i == 2:
+                    # Second & third rows without bold => judge name!
+                    presiding_re = re.compile(", (presiding|panel 1)$")
+                    referral_re = re.compile(", referral$")
+                    if presiding_re.search(line):
+                        data[u"assigned_to_str"] = presiding_re.sub("", line)
+                    elif referral_re.search(line):
+                        data[u"referred_to_str"] = referral_re.sub("", line)
+                    else:
+                        raise AssertionError(
+                            "Unable to match judge row: %s" % line
+                        )
                 else:
-                    raise AssertionError("Line with no boldface?")
+                    raise AssertionError("Line with no boldface: '%s'" % line)
             for bold in bolds:
                 data.update(
                     self._get_label_value_pair(bold, True, field_names)
@@ -202,25 +219,25 @@ class CaseQuery(BaseDocketReport, BaseReport):
         """
 
         """
-        This is an example of a query that could be sent, and which we're 
+        This is an example of a query that could be sent, and which we're
         attempting to replicate:
-            curl 'https://ecf.ord.uscourts.gov/cgi-bin/iquery.pl?1-L_1_0-1' 
-                -H 'Content-Type: multipart/form-data; boundary=----WebKitFormBoundary7Sz5UdWuoi5TbtDj' 
-                -H 'Referer: https://external' 
-                -H 'Cookie: CASE_NUM=6:16-cv-01710(128548); PacerSession=xxx; PacerPref=receipt=Y' 
+            curl 'https://ecf.ord.uscourts.gov/cgi-bin/iquery.pl?1-L_1_0-1'
+                -H 'Content-Type: multipart/form-data; boundary=----WebKitFormBoundary7Sz5UdWuoi5TbtDj'
+                -H 'Referer: https://external'
+                -H 'Cookie: CASE_NUM=6:16-cv-01710(128548); PacerSession=xxx; PacerPref=receipt=Y'
                 --data-binary $'------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
                     name="UserType"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
-                    name="all_case_ids"\r\n\r\n128548\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="case_num"\r\n\r\n6:16-cv-1710\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="Qry_filed_from"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="Qry_filed_to"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="lastentry_from"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="lastentry_to"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="last_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="first_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
-                    name="middle_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data; 
+                    name="all_case_ids"\r\n\r\n128548\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="case_num"\r\n\r\n6:16-cv-1710\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="Qry_filed_from"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="Qry_filed_to"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="lastentry_from"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="lastentry_to"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="last_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="first_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
+                    name="middle_name"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj\r\nContent-Disposition: form-data;
                     name="person_type"\r\n\r\n\r\n------WebKitFormBoundary7Sz5UdWuoi5TbtDj--\r\n'
-                    
+
         The important notes, from testing:
          - The CASE_NUM cookie isn't needed.
          - The case_num parameter needs a value; any value will do.
@@ -228,7 +245,7 @@ class CaseQuery(BaseDocketReport, BaseReport):
         """
         assert (
             self.session is not None
-        ), "session attribute of DocketReport cannot be None."
+        ), "session attribute of CaseQuery report cannot be None."
         assert bool(pacer_case_id), (
             "pacer_case_id must be truthy, not '%s'" % pacer_case_id
         )
@@ -245,7 +262,11 @@ class CaseQuery(BaseDocketReport, BaseReport):
             u"middle_name": "",
             u"person_type": "",
         }
-        logger.info(u"Running case query for case ID '%s'", pacer_case_id)
+        logger.info(
+            u"Running case query for case ID '%s' in court '%s'",
+            pacer_case_id,
+            self.court_id,
+        )
         self.response = self.session.post(self.url + "?1-L_1_0-1", data=params)
         self.parse()
 
