@@ -48,6 +48,13 @@ class BaseDocketReport(object):
     docket_number_bankr_regex = re.compile(r"(?:#:\s+)?((\d-)?\d\d-\d*)")
     docket_number_jpml = re.compile(r"(MDL No.\s+\d*)")
 
+    def __init__(self, court_id):
+        self.court_id = court_id
+        if self.court_id.endswith("b"):
+            self.is_bankruptcy = True
+        else:
+            self.is_bankruptcy = False
+
     def _clear_caches(self):
         """Clear any caches that are on the object."""
         for attr in self.CACHE_ATTRS:
@@ -138,6 +145,30 @@ class BaseDocketReport(object):
         else:
             return s
 
+    def _parse_docket_number_strs(self, potential_docket_numbers):
+        """Parse docket numbers from a list of potential ones
+
+        :param potential_docket_numbers: Potential docket number unicode
+        objects
+        :type potential_docket_numbers: list
+        :return: The correct docket number
+        :rtype: unicode
+        """
+        if self.is_bankruptcy:
+            # Uses both b/c sometimes the bankr. cases have a dist-style docket
+            # number.
+            regexes = [
+                self.docket_number_dist_regex,
+                self.docket_number_bankr_regex,
+            ]
+        else:
+            regexes = [self.docket_number_dist_regex, self.docket_number_jpml]
+        for regex in regexes:
+            for s in potential_docket_numbers:
+                match = regex.search(s)
+                if match:
+                    return match.group(1)
+
     def get_datetime_from_tree(self, path, cast_to_date=False):
         """Parse a datetime from the XML located at node.
 
@@ -221,16 +252,18 @@ class BaseDocketReport(object):
         label = node.text_content().strip()
         if require_colon and not label.endswith(":"):
             return {}
+        if isinstance(label, str):
+            label = label.decode("utf-8")
+
         label = (
             label.strip()
             .lower()
             .replace(" ", "_")
+            .replace(u"\xa0", "_")  # Non-breaking space
             .replace("(", "")
             .replace(")", "")
             .rstrip(":")
         )
-        if six.PY2:
-            label = label.decode("utf-8")
         label = field_mappings.get(label, label)
 
         value = node.tail.strip()
@@ -323,18 +356,15 @@ class DocketReport(BaseDocketReport, BaseReport):
     ]
 
     def __init__(self, court_id, pacer_session=None):
-        super(DocketReport, self).__init__(court_id, pacer_session)
+        BaseDocketReport.__init__(self, court_id)
+        BaseReport.__init__(self, court_id, pacer_session)
+
         # Initialize the empty cache properties.
         self._clear_caches()
         self._metadata = None
         self._parties = None
         self._docket_entries = None
 
-        if self.court_id.endswith("b"):
-            self.is_bankruptcy = True
-        else:
-            self.is_bankruptcy = False
-
     def parse(self):
         """Parse the item, but be sure to clear the cache before you do so.
 
@@ -346,6 +376,9 @@ class DocketReport(BaseDocketReport, BaseReport):
 
     @property
     def metadata(self):
+        if self.is_valid is False:
+            return {}
+
         if self._metadata is not None:
             return self._metadata
 
@@ -1185,22 +1218,11 @@ class DocketReport(BaseDocketReport, BaseReport):
     def _get_docket_number(self):
         if self.is_bankruptcy:
             docket_number_path = "//font"
-            # Uses both b/c sometimes the bankr. cases have a dist-style docket
-            # number.
-            regexes = [
-                self.docket_number_dist_regex,
-                self.docket_number_bankr_regex,
-            ]
         else:
             docket_number_path = "//h3"
-            regexes = [self.docket_number_dist_regex, self.docket_number_jpml]
         nodes = self.tree.xpath(docket_number_path)
         string_nodes = [s.text_content() for s in nodes]
-        for regex in regexes:
-            for s in string_nodes:
-                match = regex.search(s)
-                if match:
-                    return match.group(1)
+        return self._parse_docket_number_strs(string_nodes)
 
     def _get_nature_of_suit(self):
         if self.is_adversary_proceeding:
@@ -1221,18 +1243,16 @@ class DocketReport(BaseDocketReport, BaseReport):
             return self._get_value(self.nos_regex, self.metadata_values)
 
     def _get_judge(self, regex):
-        judge_str = self._get_value(re.compile(regex), self.metadata_values)
+        judge_regex = re.compile(regex, flags=re.DOTALL | re.IGNORECASE)
+        judge_str = self._get_value(judge_regex, self.metadata_values)
         if judge_str:
             return normalize_judge_string(judge_str)[0]
         else:
             # No luck getting it in the metadata_values attribute. Broaden
             # the search to look in the entire docket HTML.
-            path = '//*[re:match(text(), "%s")]' % regex
-            try:
-                judge_str = self.tree.re_xpath(path)[0].text_content()
-            except IndexError:
-                return ""
-            judge_str = judge_str.split("to:")[1]
+            text_nodes = self.tree.xpath("//text()")
+            text_nodes = [t for t in text_nodes if t and not t.isspace()]
+            judge_str = self._get_value(judge_regex, text_nodes)
             return normalize_judge_string(judge_str)[0]
 
 
