@@ -6,7 +6,7 @@ from requests.packages.urllib3 import exceptions
 from ..lib.exceptions import PacerLoginException
 from ..lib.html_utils import get_html_parsed_text, get_xml_parsed_text
 from ..lib.log_tools import make_default_logger
-from ..pacer.utils import is_pdf
+from ..pacer.utils import is_pdf, is_text
 
 logger = make_default_logger()
 
@@ -23,7 +23,10 @@ def check_if_logged_in_page(text):
     :return boolean: True if logged in, False if not.
     """
     valid_case_number_query = (
-        "<case number=" in text or "<request number=" in text
+        "<case number=" in text
+        or "<request number=" in text
+        or 'id="caseid"' in text
+        or "Cost: " in text
     )
     no_results_case_number_query = re.search("<message.*Cannot find", text)
     sealed_case_query = re.search("<message.*Case Under Seal", text)
@@ -394,6 +397,9 @@ class PacerSession(requests.Session):
         if is_pdf(r):
             return False
 
+        if is_text(r):
+            return False
+
         logged_in = check_if_logged_in_page(r.text)
         if logged_in:
             return False
@@ -405,9 +411,7 @@ class PacerSession(requests.Session):
             self.login()
             return True
         else:
-            msg = (
-                u"Invalid/expired PACER session and do not have "
-                u"credentials for re-login."
+            raise PacerLoginException(
+                u"Invalid/expired PACER session and do not have credentials "
+                u"for re-login."
             )
-            logger.error(msg)
-            raise PacerLoginException(msg)
